]> git.xonotic.org Git - xonotic/darkplaces.git/blobdiff - sys.h
sys: optimise printing to stdout
[xonotic/darkplaces.git] / sys.h
diff --git a/sys.h b/sys.h
index 119748ed8448c41ca241c3c012c37825389c3dfe..2255a6a3064502f597341232da317e9eb089d470 100644 (file)
--- a/sys.h
+++ b/sys.h
@@ -208,8 +208,9 @@ char *Sys_TimeString(const char *timeformat);
 void Sys_Error (const char *error, ...) DP_FUNC_PRINTF(1) DP_FUNC_NORETURN;
 
 /// (may) output text to terminal which launched program
-void Sys_Print(const char *text);
-/// for the console to report failures inside Con_Printf()
+/// textlen excludes any (optional) \0 terminator
+void Sys_Print(const char *text, size_t textlen);
+/// used to report failures inside Con_Printf()
 void Sys_Printf(const char *fmt, ...);
 
 /// INFO: This is only called by Host_Shutdown so we dont need testing for recursion